%global module_name mwlib

Name:           python-%{module_name}
Version:        0.15.19
Release:        3%{?dist}
Summary:        MediaWiki parser and utility library

License:        BSD
URL:            http://pediapress.com/code/
Source0:        https://pypi.python.org/packages/5f/55/e0096ec5aab8d5c3b51af07473d4a3d987a5048ec5647c4ba6c8750ca87a/mwlib-%{version}.zip
Source1:        README.fedora

# Removes the following "requires" from setup.py for these reasons:
#   roman: part of python-docutils
#   timelib: replaced with dateutil
Patch0:         mwlib-clean-up-dependencies.patch

# Replaces timelib with dateutil
Patch1:         mwlib-replace-timelib-with-dateutil.patch

# Ensure all console scripts are prefixed with 'mw-'
Patch2:         mwlib-prefix-console-scripts.patch

# Skip some failing tests
Patch3:         skip-odflint.patch
Patch4:         skip-ploticus.patch

BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  perl-generators
BuildRequires:  python2-devel
BuildRequires:  python2-setuptools
BuildRequires:  python2-odfpy >= 0.9
BuildRequires:  pyPdf >= 1.12
BuildRequires:  python2-pyparsing >= 1.4.11
BuildRequires:  python2-apipkg >= 1.2
BuildRequires:  python2-bottle >= 0.10
BuildRequires:  python2-dateutil
BuildRequires:  python2-docutils
BuildRequires:  python2-gevent
BuildRequires:  python2-lxml
BuildRequires:  python2-pillow
BuildRequires:  python2-py >= 1.4
BuildRequires:  python2-qserve >= 0.2.7
BuildRequires:  python2-simplejson >= 2.3
BuildRequires:  python2-sqlite3dbm
BuildRequires:  python2-roman
BuildRequires:  python2-pytest

%global _description \
mwlib provides a library for parsing MediaWiki articles and converting them to\
different output formats. mwlib is used by Wikipedia's "Print/export" feature\
in order to generate PDF documents from Wikipedia articles.

%description %_description

%package -n python2-%{module_name}
Summary: %summary
Requires:       python2-odfpy >= 0.9
Requires:       pyPdf >= 1.12
Requires:       python2-pyparsing >= 1.4.11
Requires:       python2-apipkg >= 1.2
Requires:       python2-bottle >= 0.10
Requires:       python2-dateutil
Requires:       python2-docutils
Requires:       python2-gevent
Requires:       python2-lxml
Requires:       python2-pillow
Requires:       python2-py >= 1.4
Requires:       python2-qserve >= 0.2.7
Requires:       python2-setuptools
Requires:       python2-simplejson >= 2.3
Requires:       python2-sqlite3dbm
Requires:       python2-roman
%{?python_provide:%python_provide python2-%{module_name}}

%description -n python2-%{module_name} %_description

%prep
%autosetup -n %{module_name}-%{version} -p1

sed -i '/^#!/d' mwlib/*.py mwlib/*/*.py mwlib/snippets.txt
chmod a-x mwlib/*.py mwlib/*/*.py mwlib/snippets.txt


%build
%py2_build

%install
%py2_install
mkdir -p %{buildroot}%{_datadir}/%{module_name}
rm %{buildroot}%{python2_sitearch}/%{module_name}/templ/*.c

cp %{SOURCE1} ./

%check
# imports from mwlib don't work without this for some reason
touch %{buildroot}%{python2_sitearch}/mwlib/__init__.py

# enforce importing from the installation directory
sed -i 's/sys\.path\.append.*//' conftest.py
PATH=%{buildroot}%{_bindir}:$PATH \
   PYTHONPATH=%{buildroot}%{python2_sitearch} \
   py.test-%{python2_version} -v tests/ \
       --ignore tests/test_nserve.py \
       --ignore tests/test_redirect.py \
       --ignore tests/test_zipwiki.py \
       --ignore tests/test_nuwiki.py \
       -k 'not test_codes and not test_time_minus_days and not test_snippets'
# 1. wsgi_intercept is missing
# 2. rl renderer is missing
# 3. no network
# 4. https://github.com/pediapress/mwlib/issues/51

rm %{buildroot}%{python2_sitearch}/mwlib/__init__.py

%files -n python2-%{module_name}
%doc changelog.rst README.rst README.fedora docs
%{python2_sitearch}/*
%{_bindir}/mw-*
%{_datadir}/%{module_name}


%changelog
* Sat Jul 14 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.15.19-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Mon Mar 26 2018 Iryna Shcherbina <ishcherb@redhat.com> - 0.15.19-2
- Update Python 2 dependency declarations to new packaging standards
  (See https://fedoraproject.org/wiki/FinalizingFedoraSwitchtoPython3)

* Thu Mar 15 2018 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 0.15.19-1
- Next upstream release with very minor changes (#1424168, #1526655)

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.15.14-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Sat Aug 19 2017 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 0.15.14-10
- Python 2 binary package renamed to python2-mwlib
  See https://fedoraproject.org/wiki/FinalizingFedoraSwitchtoPython3

* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.15.14-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.15.14-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Fri Jul 07 2017 Igor Gnatenko <ignatenko@redhat.com> - 0.15.14-7
- Rebuild due to bug in RPM (RHBZ #1468476)

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.15.14-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.15.14-5
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.15.14-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.15.14-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat May 02 2015 Kalev Lember <kalevlember@gmail.com> - 0.15.14-2
- Rebuilt for GCC 5 C++11 ABI change

* Fri Jan 30 2015 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 0.15.14-1
- Update to 0.15.14 and enable tests (#1031279)

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.15.11-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.15.11-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sun Aug 18 2013 Ian Weller <iweller@redhat.com> - 0.15.11-2
- Prefix all console scripts with mw- (RHBZ 998164)

* Tue Aug 13 2013 Ian Weller <iweller@redhat.com> - 0.15.11-1
- Update to 0.15.11

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.14.3-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Wed Jul 17 2013 Petr Pisar <ppisar@redhat.com> - 0.14.3-2
- Perl 5.18 rebuild

* Tue Jan 29 2013 Ian Weller <iweller@redhat.com> - 0.14.3-1
- Update to upstream 0.14.3

* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.13.8-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Sat Jun 16 2012 Ian Weller <iweller@redhat.com> - 0.13.8-1
- Update to 0.13.8

* Tue Mar 13 2012 Ian Weller <iweller@redhat.com> - 0.13.6-1
- enhancement: implement protocol relative urls in named links
- enhancement: make mw-zip -gg post test.pediapress.com

* Mon Mar 05 2012 Ian Weller <iweller@redhat.com> - 0.13.5-1
- Update to 0.13.5 upstream

* Wed Feb 15 2012 Ian Weller <iweller@redhat.com> - 0.13.4-1
- Update to 0.13.4 upstream
- Update Requires: python-qserve >= 0.2.7
- Add Requires: python-simplejson
- Rebase Patch0 (Clean up dependencies)
- Rebase Patch1 (Unbundle apipkg)
- Rename patches to not be version-specific
- rm rm -rf buildroot

* Mon Feb 13 2012 Ian Weller <iweller@redhat.com> - 0.13.3-4
- Requires: python-setuptools

* Mon Feb 13 2012 Ian Weller <iweller@redhat.com> - 0.13.3-3
- BuildRequires: python-setuptools

* Sat Feb 11 2012 Ian Weller <iweller@redhat.com> - 0.13.3-2
- Move off of py.apipkg into the separate module
- Do a better job of unbundling apipkg completely
- Fix provides filtering

* Fri Jan 13 2012 Ian Weller <iweller@redhat.com> - 0.13.3-1
- Initial package build (again)
